@@ -67,7 +67,6 @@
 #define SIZEOF_TIME_T 8
 #define SIZEOF_CLOCK_T 8
 #define PACKED_STRUCT(x) x __attribute__((packed))
-#define PACKED_STRUCT_UNALIGNED(x) x
 #define PRI_LL_PREFIX "ll"
 #define rb_pid_t pid_t
 #define SIGNEDNESS_OF_PID_T -1
@@ -234,8 +233,10 @@
 #define HAVE_FCHMOD 1
 #define HAVE_FCHOWN 1
 #define HAVE_FCNTL 1
+#define HAVE_FDOPENDIR 1
 #define HAVE_FGETATTRLIST 1
 #define HAVE_FMOD 1
+#define HAVE_FSTATAT 1
 #define HAVE_FSYNC 1
 #define HAVE_FTRUNCATE 1
 #define HAVE_GETATTRLIST 1
@@ -262,6 +263,7 @@
 #define HAVE_LOCKF 1
 #define HAVE_LOG2 1
 #define HAVE_LSTAT 1
+#define HAVE_LUTIMES 1
 #define HAVE_MALLOC_SIZE 1
 #define HAVE_MBLEN 1
 #define HAVE_MEMSET_S 1
@@ -269,9 +271,11 @@
 #define HAVE_MKFIFO 1
 #define HAVE_MKNOD 1
 #define HAVE_MKTIME 1
+#define HAVE_OPENAT 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_MEMALIGN 1
 #define HAVE_PREAD 1
+#define HAVE_PWRITE 1
 #define HAVE_QSORT_R 1
 #define HAVE_READLINK 1
 #define HAVE_ROUND 1
@@ -327,15 +331,10 @@
 #define HAVE_BUILTIN___BUILTIN_TYPES_COMPATIBLE_P 1
 #define HAVE_BSD_QSORT_R 1
 #define ATAN2_INF_C99 1
-#define LGAMMA_R_PM0_FIX 1
 #define HAVE_STRUCT_TM_TM_ZONE 1
 #define HAVE_TM_ZONE 1
 #define HAVE_STRUCT_TM_TM_GMTOFF 1
 #define HAVE_DAYLIGHT 1
-#define HAVE_VAR_TIMEZONE 1
-#define TYPEOF_VAR_TIMEZONE long
-#define HAVE_TIMEZONE 1
-#define TIMEZONE_VOID 1
 #define NEGATIVE_TIME_T 1
 #define POSIX_SIGNAL 1
 #define HAVE_SIG_T 1
@@ -348,13 +347,13 @@
 #define HAVE_SCHED_YIELD 1
 #define HAVE_PTHREAD_ATTR_SETINHERITSCHED 1
 #define HAVE_PTHREAD_ATTR_GETSTACK 1
+#define HAVE_PTHREAD_ATTR_INIT 1
 #define HAVE_PTHREAD_GET_STACKADDR_NP 1
 #define HAVE_PTHREAD_GET_STACKSIZE_NP 1
 #define HAVE_PTHREAD_COND_INIT 1
 #define HAVE_PTHREAD_CONDATTR_INIT 1
 #define HAVE_PTHREAD_SIGMASK 1
 #define HAVE_PTHREAD_SETNAME_NP 1
-#define HAVE_PTHREAD_ATTR_INIT 1
 #define SET_CURRENT_THREAD_NAME(name) pthread_setname_np(name)
 #define DEFINE_MCONTEXT_PTR(mc, uc) mcontext_t mc = (uc)->uc_mcontext
 #define HAVE_EXECINFO_H 1
